# Framework Specification

## Documents

Read in order:

| # | Document | Description |
|---|----------|-------------|
| 1 | [Goals](01-goals.md) | Purpose, core thesis, design principles |
| 2 | [Learning Methods](02-learning-methods.md) | Comprehensive reference of LLM customization techniques |
| 3 | [Framework Strategy](03-framework-strategy.md) | Which approaches we use and why |
| 4 | [Architecture](04-architecture.md) | System components and data flows |
| 5 | [Data Model](05-data-model.md) | Database schemas |
| 6 | [Context Routing](06-context-routing.md) | Hybrid routing architecture for context selection |
| 7 | [Advanced Methods](07-advanced-methods.md) | Pipeline architecture for intelligent adaptation |

## Quick Links

**What is this?** → [Goals](01-goals.md)

**What techniques exist?** → [Learning Methods](02-learning-methods.md)

**What are we building?** → [Framework Strategy](03-framework-strategy.md)

**How does it work?** → [Architecture](04-architecture.md)

**How to build intelligent methods?** → [Advanced Methods](07-advanced-methods.md)
